@@ -3,16 +3,22 @@
 
 ### "Arith", "Compare",..., are in ./Arith.R
 ###  ----                            ~~~~~~~
+if(FALSE)
+    print(getGroupMembers("Math"), width = 85)
+##  [1] "abs"      "sign"     "sqrt"     "ceiling"  "floor"    "trunc"    "cummax"
+##  [8] "cummin"   "cumprod"  "cumsum"   "exp"      "expm1"    "log"      "log10"
+## [15] "log2"     "log1p"    "cos"      "cosh"     "sin"      "sinh"     "tan"
+## [22] "tanh"     "acos"     "acosh"    "asin"     "asinh"    "atan"     "atanh"
+## [29] "cospi"    "sinpi"    "tanpi"    "gamma"    "lgamma"   "digamma"  "trigamma"
 
-## [1] "abs"    "sign"    "sqrt"    "ceiling" "floor" "trunc" "cummax"
-## [8] "cummin" "cumprod" "cumsum"  "exp"     "expm1" "log"   "log10"
-##[15] "log2"   "log1p"   "cos"     "cosh"    "sin"   "sinh"  "tan"
-##[22] "tanh"   "acos"    "acosh"   "asin"    "asinh" "atan"  "atanh"
-##[29] "gamma"  "lgamma"  "digamma" "trigamma"
-
-if(FALSE) ## here are the individual function
+if(FALSE) ## the individual functions
     dput(getGroupMembers("Math"))
 
+## NOTA BENE:  explicitly in {Math} in
+## >>>>  ../man/mpfr-class.Rd <<<<
+##          ~~~~~~~~~~~~~~~~~
+
+
 ## Uniform interface to C:
 ##
 ## Pass integer code to call and do the rest in C
@@ -154,7 +160,7 @@ chooseMpfr <- function(a, n, rnd.mode = c('N','D','U','Z','A')) {
     } else if((ln <- length(n)) != 1 && ln != length(a))
 	a <- a + 0*n
     setDataPart(a, .Call(R_mpfr_choose, a, n, match.arg(rnd.mode)))
-}
+} ##                     ------------- => ../src/utils.c
 
 chooseMpfr.all <- function(n, precBits=NULL, k0=1, alternating=FALSE) {
     ## return   chooseMpfr(n, k0:n) or (-1)^k * choose...  "but smartly"
